==> haskell-quickcheck-assertions-0.3.0-280-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-FVRN26d6igy7KlJi4bvUbg
key:                  quickcheck-assertions-0.3.0-FVRN26d6igy7KlJi4bvUbg
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  fd3ba434b733d94cc68f392debb21a2b
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-FVRN26d6igy7KlJi4bvUbg
depends:
    QuickCheck-2.14.3-FZiRXTXSsGZ9xX5Wd8RRwa base-4.16.4.0
    ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-281-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-8ziDouRYBvFGW5E4li8K0c
key:                  quickcheck-assertions-0.3.0-8ziDouRYBvFGW5E4li8K0c
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  416fb7d307a19d49e8c33eda06035dfe
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-8ziDouRYBvFGW5E4li8K0c
depends:
    QuickCheck-2.14.3-2fwOGp9PorUAao68q5lrRL base-4.16.4.0
    ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
